Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(326)

Unified Diff: chrome/browser/chromeos/net/network_portal_notification_controller.h

Issue 2698473007: Convert path usage in NetworkListViewBase subclasses to use guids. (Closed)
Patch Set: Tweak NetworkPortalNotificationControllerTest to create GUIDs for new NetworkStates. Created 3 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/chromeos/net/network_portal_notification_controller.h
diff --git a/chrome/browser/chromeos/net/network_portal_notification_controller.h b/chrome/browser/chromeos/net/network_portal_notification_controller.h
index 61224e1b35e0cc55d7dee506c73cf83b5d7c6567..635d104c96c037c60f7de23b98acebe379c72e44 100644
--- a/chrome/browser/chromeos/net/network_portal_notification_controller.h
+++ b/chrome/browser/chromeos/net/network_portal_notification_controller.h
@@ -125,8 +125,8 @@ class NetworkPortalNotificationController
const NetworkState* network,
const NetworkPortalDetector::CaptivePortalState& state) override;
- // Last network path for which notification was displayed.
- std::string last_network_path_;
+ // Last network guid for which notification was displayed.
+ std::string last_network_guid_;
// Backpointer to owner.
NetworkPortalDetector* network_portal_detector_ = nullptr;
« no previous file with comments | « ash/mus/system_tray_delegate_mus.cc ('k') | chrome/browser/chromeos/net/network_portal_notification_controller.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698